summaryrefslogtreecommitdiffstats
path: root/korn/kornboxcfgimpl.h
diff options
context:
space:
mode:
Diffstat (limited to 'korn/kornboxcfgimpl.h')
-rw-r--r--korn/kornboxcfgimpl.h26
1 files changed, 13 insertions, 13 deletions
diff --git a/korn/kornboxcfgimpl.h b/korn/kornboxcfgimpl.h
index 73cf7bb5..5bc82c44 100644
--- a/korn/kornboxcfgimpl.h
+++ b/korn/kornboxcfgimpl.h
@@ -21,8 +21,8 @@
#include "kornboxcfg.h"
-class KConfig;
-class KConfigGroup;
+class TDEConfig;
+class TDEConfigGroup;
class KDialogBase;
class TQFont;
@@ -37,20 +37,20 @@ public:
~KornBoxCfgImpl();
/**
* This method write the current configuration to a specified KConfig-object.
*
* @param config The config where in which the configuration should be added.
* @param index The index of the selected config. This is the group-number.
*/
- void writeConfig( KConfig * config, const int index );
+ void writeConfig( TDEConfig * config, const int index );
/**
* This method write the current configuration to a specified KConfig-object.
*
* @param config The config where in which the configuration should be added. Note that this object is stored locally until the object is destroyed.
* @param index The index of the selected config. This is the group-number.
*/
- void readConfig( KConfig * config, const int index );
+ void readConfig( TDEConfig * config, const int index );
private:
void readViewConfig();
@@ -58,13 +58,13 @@ private:
void readAccountsConfig();
void readDCOPConfig();
- void writeViewConfig( KConfig* config );
- void writeEventConfig( KConfig *config );
- void writeAccountsConfig( KConfig *config );
- void writeDCOPConfig( KConfig *config );
+ void writeViewConfig( TDEConfig* config );
+ void writeEventConfig( TDEConfig *config );
+ void writeAccountsConfig( TDEConfig *config );
+ void writeDCOPConfig( TDEConfig *config );
- KConfig* _config;
- KConfigGroup *_group;
+ TDEConfig* _config;
+ TDEConfigGroup *_group;
KDialogBase *_base;
int _index;
TQString *_anims[ 2 ];
@@ -74,7 +74,7 @@ protected slots:
virtual void slotEditBox();
virtual void slotActivated( const TQString& );
virtual void slotActivated( const int );
- virtual void slotSetDefaults( const TQString&, const int, KConfig* );
+ virtual void slotSetDefaults( const TQString&, const int, TDEConfig* );
virtual void slotChangeNormalAnim();
virtual void slotChangeNewAnim();
virtual void slotChangeNormalFont();
@@ -37,20 +37,20 @@ public:
~KornBoxCfgImpl();
/**
- * This method write the current configuration to a specified KConfig-object.
+ * This method write the current configuration to a specified TDEConfig-object.
*
* @param config The config where in which the configuration should be added.
@@ -37,20 +37,20 @@ public:
/**
- * This method write the current configuration to a specified KConfig-object.
+ * This method write the current configuration to a specified TDEConfig-object.
*
* @param config The config where in which the configuration should be added. Note that this object is stored locally until the object is destroyed.